<div class="peek-ds-footer peek-footer-bar"
      *ngIf="isEnabled"
     [class.bg-danger]="!vortexIsOnline">
    <div class="container">
        <div class="row">
            <div class="footer-bar-footer">
                {{statusText}}
            </div>
        </div>
        <div class="row">
            <div class="pull-right">
                <button class="peek-ds-f-buttons">
                    <fa name="cog" tooltip="User Configuration"></fa>
                </button>
            </div>
        </div>
    </div>
</div>
