@import '~@synerty/peek-theme/scss/_variables.web';

.peek-desktop {
    height: 100%;
}

.peek-desktop-sidebar {
    height: 100%;
    width: $desktop_side_bar_width;
    position: fixed;
    z-index: 1;
    top: 0;
    left: 0;
    overflow-x: hidden;
    background-image: url('/assets/sidebar_background.png');
}


.peek-desktop-content {
    height: 100%;
    margin-left: $desktop_side_bar_width;
    left: $desktop_side_bar_width;
    overflow-y: scroll;
}
