@import '~@synerty/peek-theme/scss/_variables.web';


.peek-dc-home-background {
    height: 100%;
    background-image: url('/assets/home-background.png');
    background-size: contain;
    background-position: center;
    background-repeat: no-repeat;
    background-color: $black;
}

.peek-dc-home-logo {
    height: 100%;
    display: block;
    margin: auto;
}
